@@ -94,7 +94,7 @@ def activate_complete(request, template_name='accounts/activate_complete.html',
 
 
 def activate(request, template_name='accounts/activate.html',
-             success_url=None, extra_context=None, **kwargs):
+             success_url='/accounts/activate/complete/', extra_context=None, **kwargs):
     user = get_user_model().objects.activate_user(**kwargs)
 
     if user:
